#include "vis.h"

int EXPORT_PUBLIC libfunc(void) {
    return 3;
}
